---
title: SixueTree 树形控件
---

本 Demo 演示形控件扩展更多操作，包括：重命名、添加子分组、上移、下移、置顶、置底、（删除/停启用）

```jsx
import React, { useState } from 'react';
import { Button } from '@alifd/next';
import SixueTree from 'sixue-tree';

const data1 = [{
  "key": "1", // 参数 key
  "label": "野生动物", // 展示名称
  "group": true, // 是否是分组
  "enabled": true, // 是否启用
  "parentId": "0",
  "sort": 0,
  "children": [{
    "key": "8",
    "label": "肉食类动物",
    "group": true,
    "enabled": false,
    "parentId": "1",
    "sort": 2,
    "children": []
  }, {
    "key": "30",
    "label": "商品品类",
    "group": false,
    "enabled": true,
    "parentId": "1",
    "sort": 2,
    "children": []
  }]
}, {
  "key": "59",
  "label": "动物园动物园动物物",
  "group": true,
  "enabled": true,
  "parentId": "0",
  "sort": 24,
  "children": []
}, {
  "key": "61",
  "label": "猫",
  "group": true,
  "enabled": true,
  "parentId": "0",
  "sort": 30,
  "children": []
}]

export default function TreeView() {
  const [treeData, setTreeData] = useState(data1);
  const [selected, setSelected] = useState(['1']);
  const [expand, setExpand] = useState(['1']);
  const [treeItemInfo, setTreeItemInfo] = useState(Array || Object);

  const rename = () => {
    // 接口成功后执行
    treeItemInfo.label = `${treeItemInfo.label} - rename`;
    setTreeData([...treeData]);
  };

  const addChild = () => {
    // 接口成功后执行
    treeItemInfo.children.push({
      label: '子分组',
      key: '10006',
      group: true,
      enabled: true,
     });
    setTreeData([...treeData]);
  };

  const enableDisable = (type) => {
    console.log(type ? '启用' : '停用');
    // 接口成功后执行
    treeItemInfo.enabled = !treeItemInfo.enabled;
    setTreeData([...treeData]);
  };

  const move = (type) => {
    // 接口成功后执行
    treeFunc(type, treeData)
  };

  const remove = (type) => {
    // 接口成功后执行
    treeFunc(type, treeData);
  };

  const treeFunc = (type, data) => {
    try {
      data.forEach((item, index) => {
        if (treeItemInfo.key === item.key) {
          // 删除
          if (type === 'delete') {
             data.splice(index, 1);
          }
          // 上移
          if (type === 'up') {
            data.splice(index, 1);
            data.splice(index - 1, 0, item);
          }
          // 下移
          if (type === 'down') {
            data.splice(index, 1);
            data.splice(index + 1, 0, item);
          }
          // 置顶
          if (type === 'top') {
            data.splice(index, 1);
            data.unshift(item);
          }
          // 置底
          if (type === 'bottom') {
            data.splice(index, 1);
            data.push(item);
          }
          setTreeData([...treeData]);
          throw Error();
        }
        if (item.children) {
          treeFunc(type, item.children);
        }
      });
    } catch (e) {
      e;
    }
  }
  
  const onChange = (info) => {
    // 当前tree选中信息
    // console.log(info);
    setTreeItemInfo(info);
  };

  return (
    <div style={{position: 'relative', width: '100%', height: '500px', display: 'flex'}}>
      <div style={{display: 'flex', width: '400px', padding: '40px 26px 0'}}>
        <Button
          type='primary'
          style={{position: 'absolute',top: '0'}}
          onClick={() => {
            treeData.push({ label: '小蚂蚁', key: '105', group: true, enabled: false });
            setTreeData([...treeData]);
          }}
        >
          新建分组
        </Button>
        <SixueTree
          dataSource={data1}
          groupingIcon='email'
          groupingMaxNum={4}
          selected={selected}
          expand={expand}
          disableShow={true}
          onChange={onChange}
          rename={rename}
          addChild={addChild}
          move={move}
          remove={remove}
          enableDisable={enableDisable}
        />
      </div>
      <div style={{flex: '1', background: '#fff'}}>
        <Button
          type='primary'
          className='buttonTop'
          onClick={() => {
            setExpand(['3']);
            setSelected(['3-1']);
          }}
        >
          setExpand方法展开分组
        </Button>
      </div>
    </div>
  )
}
```
